summaryrefslogtreecommitdiffstats
path: root/perl-install/diskdrake/interactive.pm
diff options
context:
space:
mode:
authorThierry Vignaud <tv@mandriva.org>2007-11-06 15:43:05 +0000
committerThierry Vignaud <tv@mandriva.org>2007-11-06 15:43:05 +0000
commit0cec176f0607443bf3019af2e9e6fa25f0441b10 (patch)
tree3a36444b75be2fc0d802f3405919d5d1933ee322 /perl-install/diskdrake/interactive.pm
parentcac00625d50a54c964a4baf8c5fe223c9a996b82 (diff)
downloaddrakx-backup-do-not-use-0cec176f0607443bf3019af2e9e6fa25f0441b10.tar
drakx-backup-do-not-use-0cec176f0607443bf3019af2e9e6fa25f0441b10.tar.gz
drakx-backup-do-not-use-0cec176f0607443bf3019af2e9e6fa25f0441b10.tar.bz2
drakx-backup-do-not-use-0cec176f0607443bf3019af2e9e6fa25f0441b10.tar.xz
drakx-backup-do-not-use-0cec176f0607443bf3019af2e9e6fa25f0441b10.zip
add support for ext4
Diffstat (limited to 'perl-install/diskdrake/interactive.pm')
-rw-r--r--perl-install/diskdrake/interactive.pm10
1 files changed, 5 insertions, 5 deletions
diff --git a/perl-install/diskdrake/interactive.pm b/perl-install/diskdrake/interactive.pm
index 2b513dd4b..a96b9e0e0 100644
--- a/perl-install/diskdrake/interactive.pm
+++ b/perl-install/diskdrake/interactive.pm
@@ -443,7 +443,7 @@ sub part_possible_actions {
my %macros = (
readonly => '$hd->{readonly}',
hasMntpoint => '$part->{mntpoint}',
- LVM_resizable => '$part->{fs_type} eq "reiserfs" || (isMounted ? $part->{fs_type} eq "xfs" : $part->{fs_type} eq "ext3")',
+ LVM_resizable => '$part->{fs_type} eq "reiserfs" || (isMounted ? $part->{fs_type} eq "xfs" : member($part->{fs_type}, qw(ext3 ext4dev)))',
canModifyRAID => 'isPartOfRAID($part) && !isMounted(fs::get::device2part($part->{raid}, $all_hds->{raids}))',
);
if (isEmpty($part)) {
@@ -590,7 +590,7 @@ sub Type {
my @types = fs::type::type_names($::expert, $hd);
#- when readonly, Type() is allowed only when changing {fs_type} but not {pt_type}
#- eg: switching between ext2, ext3, reiserfs...
@types = grep { fs::type::type_name2pt_type($_) == $part->{pt_type} } @types if $hd->{readonly};
my $type_name = fs::type::part2type_name($part);
@@ -602,8 +602,8 @@ sub Type {
my $type = $type_name && fs::type::type_name2subpart($type_name);
- if (member($type->{fs_type}, 'ext2', 'ext3')) {
- my $_w = $in->wait_message(N("Please wait"), N("Switching from ext2 to ext3"));
+ if (member($type->{fs_type}, qw(ext2 ext3 ext4dev))) {
+ my $_w = $in->wait_message(N("Please wait"), N("Switching from %s to %s", 'ext2', $type->{fs_type}));
if (run_program::run("tune2fs", "-j", devices::make($part->{device}))) {
put_in_hash($part, $type);
set_isFormatted($part, 1); #- assume that if tune2fs works, partition is formatted
@@ -713,7 +713,7 @@ sub Resize {
$nice_resize{fat} = resize_fat::main->new($part->{device}, devices::make($part->{device}));
$min = max($min, $nice_resize{fat}->min_size);
$max = min($max, $nice_resize{fat}->max_size);
- } elsif (member($part->{fs_type}, 'ext2', 'ext3')) {
+ } elsif (member($part->{fs_type}, qw(ext2 ext3 ext4dev))) {
write_partitions($in, $hd) or return;
require diskdrake::resize_ext2;
if ($nice_resize{ext2} = diskdrake::resize_ext2->new($part->{device}, devices::make($part->{device}))) {
@@ -590,7 +590,7 @@ sub Type {
my @types = fs::type::type_names($::expert, $hd);
#- when readonly, Type() is allowed only when changing {fs_type} but not {pt_type}
- #- eg: switching between ext2, ext3, reiserfs...
+ #- eg: switching between ext2, ext3, ext4dev, reiserfs...
my $type_name = fs::type::part2type_name($part);